@@ -45,13 +45,13 @@ gfu_common_seconds_to_string(guint64 seconds)
 		if (minutes >= 60) {
 			hours = minutes / 60;
 			minutes = minutes % 60;
-			return g_strdup_printf("%lu hr, %lu min, %lu sec", hours, minutes, seconds);
+			return g_strdup_printf("%u hr, %u min", (guint)hours, (guint)minutes);
 		}
 		if (seconds == 0)
-			return g_strdup_printf("%lu min", minutes);
-		return g_strdup_printf("%lu min, %lu sec", minutes, seconds);
+			return g_strdup_printf("%u min", (guint)minutes);
+		return g_strdup_printf("%u min, %u sec", (guint)minutes, (guint)seconds);
 	}
-	return g_strdup_printf("%lu sec", seconds);
+	return g_strdup_printf("%u sec", (guint)seconds);
 }
 
 gchar *
