@@ -12,14 +12,6 @@
 
 G_BEGIN_DECLS
 
-typedef enum {
-	GFU_OPERATION_UNKNOWN,
-	GFU_OPERATION_UPDATE,
-	GFU_OPERATION_DOWNGRADE,
-	GFU_OPERATION_INSTALL,
-	GFU_OPERATION_LAST
-} GfuOperation;
-
 /* formatting helper functions */
 gchar *
 gfu_common_checksum_format(const gchar *checksum);
@@ -28,14 +20,12 @@ gfu_common_seconds_to_string(guint64 seconds);
 gchar *
 gfu_common_xml_to_text(const gchar *xml, GError **error);
 const gchar *
-gfu_common_device_flags_to_strings(guint64 flags);
+gfu_common_device_flag_to_string(guint64 flags);
 const gchar *
 gfu_common_release_flags_to_strings(guint64 flags);
 const gchar *
 gfu_status_to_string(FwupdStatus status);
 gchar *
-gfu_operation_to_string(GfuOperation operation, FwupdDevice *device);
-gchar *
 gfu_common_strjoin_array(const gchar *separator, GPtrArray *array);
 
 /* handle needs-reboot and needs-shutdown */
@@ -46,7 +36,7 @@ gfu_common_system_reboot(GError **error);
 
 /* GTK helper functions */
 gchar *
-gfu_common_device_flag_to_string(guint64 device_flag);
+gfu_common_device_flags_to_string(guint64 device_flag);
 gchar *
 gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag);
 
