@@ -22,7 +22,8 @@ gfu_device_row_refresh(GfuDeviceRow *self)
 {
 	const gchar *tmp;
 	GPtrArray *icons;
-	g_autoptr(GIcon) icon = g_themed_icon_new("computer-symbolic");
+	GtkIconTheme *icon_theme = gtk_icon_theme_get_for_display(gdk_display_get_default());
+	g_autofree gchar *icon_name = NULL;
 	g_autoptr(GString) str = g_string_new(NULL);
 
 	GfuDeviceRowPrivate *priv = gfu_device_row_get_instance_private(self);
@@ -47,13 +48,23 @@ gfu_device_row_refresh(GfuDeviceRow *self)
 	/* set icon, with fallbacks */
 	icons = fwupd_device_get_icons(priv->device);
 	for (guint i = 0; i < icons->len; i++) {
-		const gchar *icon_name = g_ptr_array_index(icons, i);
-		g_autoptr(GString) icon_symbolic = g_string_new(icon_name);
+		const gchar *icon_tmp = g_ptr_array_index(icons, i);
+		g_autoptr(GString) icon_symbolic = g_string_new(icon_tmp);
+
 		if (!g_str_has_suffix(icon_symbolic->str, "-symbolic"))
 			g_string_append(icon_symbolic, "-symbolic");
-		g_themed_icon_prepend_name(G_THEMED_ICON(icon), icon_symbolic->str);
+		if (gtk_icon_theme_has_icon(icon_theme, icon_symbolic->str)) {
+			icon_name = g_string_free(g_steal_pointer(&icon_symbolic), FALSE);
+			break;
+		}
+		g_warning("did not find icon %s", icon_tmp);
 	}
-	gtk_image_set_from_gicon(GTK_IMAGE(priv->image), icon);
+
+	/* ultimate fallback */
+	if (icon_name == NULL)
+		icon_name = g_strdup("computer-chip-symbolic");
+
+	gtk_image_set_from_icon_name(GTK_IMAGE(priv->image), icon_name);
 }
 
 FwupdDevice *
