@@ -27,8 +27,6 @@ typedef struct {
 	FwupdRelease *release;
 	FwupdInstallFlags flags;
 	guint refresh_id;
-	GTimer *time_elapsed;
-	gdouble last_estimate;
 	GPtrArray *actions;
 	GPtrArray *post_requests;
 } GfuMain;
@@ -63,7 +61,7 @@ gfu_main_error_dialog(GfuMain *self, const gchar *title, const gchar *message)
 					title);
 	if (message != NULL)
 		gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog), "%s", message);
-	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), self);
+	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), NULL);
 	gtk_window_present(GTK_WINDOW(dialog));
 }
 
@@ -162,7 +160,9 @@ gfu_main_guid_instance_id_new(const gchar *instance_id, const gchar *guid)
 	/* try really hard not to wrap */
 	gtk_label_set_wrap(GTK_LABEL(label), TRUE);
 	gtk_label_set_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD_CHAR);
+#if GTK_CHECK_VERSION(4, 6, 0)
 	gtk_label_set_natural_wrap_mode(GTK_LABEL(label), GTK_NATURAL_WRAP_NONE);
+#endif
 
 	adw_action_row_add_suffix(ADW_ACTION_ROW(row), label);
 	return row;
@@ -260,6 +260,106 @@ gfu_main_set_device_flags(GfuMain *self, guint64 flags)
 	}
 }
 
+static void
+gfu_main_device_auto_verify_cb(GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+	GfuMain *self = (GfuMain *)user_data;
+	g_autoptr(GError) error = NULL;
+
+	if (!fwupd_client_verify_finish(self->client, res, &error)) {
+		g_warning("failed to verify firmware:  %s", error->message);
+		/* TRANSLATORS: the attestation failed */
+		gfu_main_set_label(self, "label_device_checksums", _("Not OK"));
+		return;
+	}
+
+	/* TRANSLATORS: the checksum verified */
+	gfu_main_set_label(self, "label_device_checksums", _("OK"));
+}
+
+#if FWUPD_CHECK_VERSION(1, 8, 1)
+static gchar *
+gfu_main_device_problem_to_string(GfuMain *self, FwupdDeviceProblem problem)
+{
+	if (problem == FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW) {
+		if (fwupd_client_get_battery_level(self->client) == FWUPD_BATTERY_LEVEL_INVALID ||
+		    fwupd_client_get_battery_threshold(self->client) ==
+			FWUPD_BATTERY_LEVEL_INVALID) {
+			/* TRANSLATORS: as in laptop battery power */
+			return g_strdup(_("System power is too low to perform the update"));
+		}
+		return g_strdup_printf(
+		    /* TRANSLATORS: as in laptop battery power */
+		    _("System power is too low to perform the update (%u%%, requires %u%%)"),
+		    fwupd_client_get_battery_level(self->client),
+		    fwupd_client_get_battery_threshold(self->client));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_UNREACHABLE) {
+		/* TRANSLATORS: for example, a Bluetooth mouse that is in powersave mode */
+		return g_strdup(_("Device is unreachable, or out of wireless range"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW) {
+		if (fwupd_device_get_battery_level(self->device) == FWUPD_BATTERY_LEVEL_INVALID ||
+		    fwupd_device_get_battery_threshold(self->device) ==
+			FWUPD_BATTERY_LEVEL_INVALID) {
+			/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
+			return g_strdup_printf(_("Device battery power is too low"));
+		}
+		/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
+		return g_strdup_printf(_("Device battery power is too low (%u%%, requires %u%%)"),
+				       fwupd_device_get_battery_level(self->device),
+				       fwupd_device_get_battery_threshold(self->device));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_UPDATE_PENDING) {
+		/* TRANSLATORS: usually this is when we're waiting for a reboot */
+		return g_strdup(_("Device is waiting for the update to be applied"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER) {
+		/* TRANSLATORS: as in, wired mains power for a laptop */
+		return g_strdup(_("Device requires AC power to be connected"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED) {
+		/* TRANSLATORS: lid means "laptop top cover" */
+		return g_strdup(_("Device cannot be used while the lid is closed"));
+	}
+	return NULL;
+}
+#endif
+
+static gchar *
+gfu_main_device_problems_to_string(GfuMain *self)
+{
+#if FWUPD_CHECK_VERSION(1, 8, 1)
+	g_autoptr(GString) str = g_string_new(NULL);
+
+	/* sanity check */
+	if (self->device == NULL)
+		return NULL;
+	if (fwupd_device_get_problems(self->device) == FWUPD_DEVICE_PROBLEM_NONE)
+		return NULL;
+
+	/* translate each problem */
+	for (guint i = 0; i < 64; i++) {
+		FwupdDeviceProblem problem = 1ull << i;
+		g_autofree gchar *tmp = NULL;
+		if (!fwupd_device_has_problem(self->device, problem))
+			continue;
+		tmp = gfu_main_device_problem_to_string(self, problem);
+		if (tmp == NULL)
+			continue;
+		g_string_append_printf(str, "%s\n", tmp);
+	}
+
+	/* success */
+	if (str->len == 0)
+		return NULL;
+	g_string_truncate(str, str->len - 1);
+	return g_string_free(g_steal_pointer(&str), FALSE);
+#else
+	return NULL;
+#endif
+}
+
 static gboolean
 gfu_main_refresh_device_cb(gpointer user_data)
 {
@@ -268,7 +368,7 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	GtkWidget *leaflet_devices =
 	    GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet_devices"));
 	GPtrArray *vendor_ids = NULL;
-	gboolean show_verify_update = TRUE;
+	g_autofree gchar *problems_str = NULL;
 	g_autoptr(GString) attr = g_string_new(NULL);
 	g_autoptr(GString) version = NULL;
 	g_autoptr(GError) error = NULL;
@@ -302,9 +402,15 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	gfu_main_set_label(self,
 			   "label_device_version_bootloader",
 			   fwupd_device_get_version_bootloader(self->device));
-	gfu_main_set_label(self,
-			   "label_device_update_error",
-			   fwupd_device_get_update_error(self->device));
+	problems_str = gfu_main_device_problems_to_string(self);
+	gfu_main_set_label(self, "label_device_problems", problems_str);
+	if (problems_str != NULL) {
+		gfu_main_set_label(self, "label_device_update_error", NULL);
+	} else {
+		gfu_main_set_label(self,
+				   "label_device_update_error",
+				   fwupd_device_get_update_error(self->device));
+	}
 	gfu_main_set_label(self, "label_device_serial", fwupd_device_get_serial(self->device));
 	gfu_main_set_label(self, "label_device_vendor", fwupd_device_get_vendor(self->device));
 	gfu_main_set_label(self, "label_device_branch", fwupd_device_get_branch(self->device));
@@ -341,17 +447,11 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	/* device can be verified immediately without hardware access */
 	if (fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_CAN_VERIFY) &&
 	    !fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE)) {
-		// FIXME async
-		if (!fwupd_client_verify(self->client,
-					 fwupd_device_get_id(self->device),
-					 self->cancellable,
-					 &error)) {
-			gfu_main_set_label(self, "label_device_checksums", error->message);
-		} else {
-			/* TRANSLATORS: the checksum verified */
-			gfu_main_set_label(self, "label_device_checksums", _("OK"));
-			show_verify_update = FALSE;
-		}
+		fwupd_client_verify_async(self->client,
+					  fwupd_device_get_id(self->device),
+					  self->cancellable,
+					  gfu_main_device_auto_verify_cb,
+					  self);
 	} else if (fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE)) {
 		/* TRANSLATORS: the checksum state was unknown */
 		gfu_main_set_label(self, "label_device_checksums", _("Unknown"));
@@ -373,7 +473,7 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "button_verify_update"));
 	gtk_widget_set_visible(
 	    w,
-	    show_verify_update && fwupd_device_get_checksums(self->device)->len > 0 &&
+	    fwupd_device_get_checksums(self->device)->len > 0 &&
 		fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_CAN_VERIFY));
 
 	/* get new releases */
@@ -622,7 +722,7 @@ gfu_main_update_releases(GfuMain *self, GPtrArray *releases)
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "listbox_releases"));
 	for (guint i = 0; i < releases->len; i++) {
 		FwupdRelease *release = g_ptr_array_index(releases, i);
-		GtkWidget *l = gfu_release_row_new(release);
+		GtkWidget *l = gfu_release_row_new(self->device, release);
 		g_debug("adding release %s", fwupd_release_get_version(release));
 		gtk_list_box_insert(GTK_LIST_BOX(w), l, -1);
 		g_signal_connect(l,
@@ -645,51 +745,17 @@ gfu_main_get_releases_cb(GObject *source, GAsyncResult *res, gpointer user_data)
 	gfu_main_update_releases(self, releases);
 }
 
-static gchar *
-gfu_main_time_remaining_str(GfuMain *self, gint percentage)
-{
-	gdouble elapsed;
-
-	elapsed = g_timer_elapsed(self->time_elapsed, NULL);
-	self->last_estimate = elapsed / percentage * (100 - percentage);
-
-	/* upgrade just started, remaining time inaccurate */
-	if (elapsed < 60)
-		return NULL;
-
-	/* this is insane */
-	if (self->last_estimate > 60 * 30)
-		return NULL;
-
-	/* less than 5 seconds remaining */
-	if (self->last_estimate < 5)
-		return NULL;
-
-	/* less than 60 seconds remaining */
-	if (self->last_estimate < 60) {
-		/* TRANSLATORS: time remaining for completing firmware flash */
-		return g_strdup(_("Less than one minute remaining"));
-	}
-
-	/* more than a minute */
-	return g_strdup_printf(
-	    /* TRANSLATORS: time remaining for completing firmware flash */
-	    ngettext("%.0f minute remaining", "%.0f minutes remaining", self->last_estimate / 60),
-	    self->last_estimate / 60);
-}
-
 static void
 gfu_main_update_progress_bar(GfuMain *self)
 {
 	GtkWidget *w = GTK_WIDGET(gtk_builder_get_object(self->builder, "progress_bar"));
+	GtkRevealer *revealer = GTK_REVEALER(gtk_builder_get_object(self->builder, "revealer"));
 	guint percentage = fwupd_client_get_percentage(self->client);
-	g_autofree gchar *remaining = NULL;
-	g_autoptr(GString) str = g_string_new(NULL);
+	FwupdStatus status = fwupd_client_get_status(self->client);
 
 	/* nothing to show */
-	if (fwupd_client_get_status(self->client) == FWUPD_STATUS_IDLE ||
-	    fwupd_client_get_status(self->client) == FWUPD_STATUS_UNKNOWN) {
-		gtk_widget_set_visible(w, FALSE);
+	if (status == FWUPD_STATUS_IDLE || status == FWUPD_STATUS_UNKNOWN) {
+		gtk_revealer_set_reveal_child(revealer, FALSE);
 		return;
 	}
 
@@ -700,18 +766,10 @@ gfu_main_update_progress_bar(GfuMain *self)
 		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(w), ((gdouble)percentage) / 100.f);
 	}
 
-	/* localized status */
-	g_string_assign(str, gfu_status_to_string(fwupd_client_get_status(self->client)));
-
-	/* estimate of time remaining */
-	remaining = gfu_main_time_remaining_str(self, fwupd_client_get_percentage(self->client));
-	if (remaining != NULL)
-		g_string_append_printf(str, ", %s…", remaining);
-
 	/* set label */
-	g_debug("status: %s [%u%%]", str->str, percentage);
-	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(w), str->str);
-	gtk_widget_set_visible(w, TRUE);
+	g_debug("status: %s [%u%%]", fwupd_status_to_string(status), percentage);
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(w), gfu_status_to_string(status));
+	gtk_revealer_set_reveal_child(revealer, TRUE);
 }
 
 static void
@@ -872,7 +930,7 @@ gfu_main_show_request_real(GfuMain *self, FwupdRequest *request, GdkPixbuf *pixb
 		gtk_box_append(GTK_BOX(box), image);
 	}
 
-	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), self);
+	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), NULL);
 	gtk_window_present(GTK_WINDOW(dialog));
 }
 
@@ -1011,7 +1069,7 @@ gfu_main_install_release_cb(GObject *source, GAsyncResult *res, gpointer user_da
 							 _("Installed firmware version %s on %s."),
 							 fwupd_release_get_version(self->release),
 							 fwupd_device_get_name(self->device));
-		g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), self);
+		g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), NULL);
 		gtk_window_present(GTK_WINDOW(dialog));
 	}
 }
@@ -1269,7 +1327,7 @@ gfu_main_device_verify_cb(GObject *source_object, GAsyncResult *res, gpointer us
 	    /* TRANSLATORS: firmware is cryptographically identical */
 	    _("%s firmware checksums matched"),
 	    fwupd_device_get_name(self->device));
-	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), self);
+	g_signal_connect(dialog, "response", G_CALLBACK(gtk_window_destroy), NULL);
 	gtk_window_present(GTK_WINDOW(dialog));
 	gfu_main_refresh_device(self);
 }
@@ -1389,7 +1447,7 @@ gfu_main_about_activated_cb(GSimpleAction *action, GVariant *parameter, gpointer
 			      "license-type",
 			      GTK_LICENSE_GPL_2_0,
 			      "logo-icon-name",
-			      "computer",
+			      "org.gnome.Firmware",
 			      "translator-credits",
 			      /* TRANSLATORS: you can put your name here :) */
 			      _("translator-credits"),
@@ -1567,7 +1625,8 @@ gfu_main_refresh_releases(GfuMain *self)
 
 	/* async call for releases */
 	if (self->device != NULL &&
-	    fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_UPDATABLE)) {
+	    (fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_UPDATABLE) ||
+	     fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN))) {
 		fwupd_client_get_releases_async(self->client,
 						fwupd_device_get_id(self->device),
 						self->cancellable,
@@ -1723,6 +1782,9 @@ gfu_main_client_connect_cb(GObject *source, GAsyncResult *res, gpointer user_dat
 	fwupd_client_set_feature_flags_async(
 	    self->client,
 	    FWUPD_FEATURE_FLAG_FDE_WARNING | FWUPD_FEATURE_FLAG_SWITCH_BRANCH |
+#if FWUPD_CHECK_VERSION(1, 8, 1)
+		FWUPD_FEATURE_FLAG_SHOW_PROBLEMS |
+#endif
 		FWUPD_FEATURE_FLAG_REQUESTS | FWUPD_FEATURE_FLAG_UPDATE_ACTION,
 	    self->cancellable,
 	    gfu_main_set_feature_flags_cb,
@@ -1849,7 +1911,6 @@ gfu_main_free(GfuMain *self)
 		g_ptr_array_unref(self->actions);
 	if (self->post_requests != NULL)
 		g_ptr_array_unref(self->post_requests);
-	g_timer_destroy(self->time_elapsed);
 	g_free(self);
 }
 
@@ -1914,7 +1975,6 @@ main(int argc, char **argv)
 			 self);
 
 	self->actions = g_ptr_array_new_with_free_func((GDestroyNotify)gtk_window_destroy);
-	self->time_elapsed = g_timer_new();
 	self->post_requests = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 
 	/* ensure single instance */
